========
Projects
========

While the default settings for an asimov project assume that you'll want to keep all of your results files and analysis configurations together in one place, there are situations where this might not be convenient.
For example, if you want webpages which are generated by a pipeline to be available in a location which is served by a public webserver.


